summaryrefslogtreecommitdiff
path: root/core/ldlinux.asm
diff options
context:
space:
mode:
authorH. Peter Anvin <hpa@zytor.com>2008-06-15 10:37:10 -0700
committerH. Peter Anvin <hpa@zytor.com>2008-06-15 10:37:10 -0700
commit89e10c2e8a7d9592a400824f9667b2487014f633 (patch)
tree2dd87978683aa44d0d4633444805e2b3984ed13e /core/ldlinux.asm
parent958ddda00522f768bf9adc86c0d5b446e0a672cf (diff)
downloadsyslinux-89e10c2e8a7d9592a400824f9667b2487014f633.tar.gz
Mechanically rename the writestr functions
Mechanically rename the writestr functions: writestr -> writestr_early cwritestr -> writestr ... to reflect which function is more appropriate to call in normal circumstances.
Diffstat (limited to 'core/ldlinux.asm')
-rw-r--r--core/ldlinux.asm14
1 files changed, 7 insertions, 7 deletions
diff --git a/core/ldlinux.asm b/core/ldlinux.asm
index 58235829..193bb064 100644
--- a/core/ldlinux.asm
+++ b/core/ldlinux.asm
@@ -623,7 +623,7 @@ ldlinux_ent:
; Tell the user we got this far
;
mov si,syslinux_banner
- call writestr
+ call writestr_early
;
; Tell the user if we're using EBIOS or CBIOS
@@ -635,7 +635,7 @@ print_bios:
mov si,ebios_name
.cbios:
mov [BIOSName],si
- call writestr
+ call writestr_early
section .bss
%define HAVE_BIOSNAME 1
@@ -697,7 +697,7 @@ verify_checksum:
; Uh-oh, something went bad...
;
mov si,checksumerr_msg
- call writestr
+ call writestr_early
jmp kaboom
;
@@ -707,11 +707,11 @@ verify_checksum:
;
;
; writestr: write a null-terminated string to the console
; This assumes we're on page 0. This is only used for early
; messages, so it should be OK.
;
-writestr:
+writestr_early:
.loop: lodsb
and al,al
jz .return
@@ -769,7 +769,7 @@ all_read:
; in Sector 1, but makes a lot more sense here.
;
mov si,copyright_str
- call writestr
+ call writestr_early
;
@@ -1281,7 +1281,7 @@ PrevDir resd 1 ; Last scanned directory
kaboom2:
mov si,err_bootfailed
- call cwritestr
+ call writestr
cmp byte [kaboom.again+1],18h ; INT 18h version?
je .int18
call getchar
@@ -707,11 +707,11 @@ verify_checksum:
;
;
-; writestr: write a null-terminated string to the console
+; writestr_early: write a null-terminated string to the console
; This assumes we're on page 0. This is only used for early
; messages, so it should be OK.